//CDDF FINAL ASSIGNMENT

// Include the AccelStepper and Adafruit Libraries:
#include <AccelStepper.h>
#include <AFMotor.h>

// Define Stepper Pins and Motor Interferance (must be 1 while using driver)
#define dirPin 2
#define stepPin 3
#define motorInterfaceType 1

// Create an instance of AccelStepper for the Glue Extruder
AccelStepper glueExtruder = AccelStepper(motorInterfaceType, stepPin, dirPin);

int glueSpeed = 3;

// 48 Steps per Revolution as per 28byj-48 Datasheet
const int stepsPerRevolution = 48;

// Set the 28byj-48 Motors for the M1/M2 and M3/M4 on the Driver
AF_Stepper rightMotor(stepsPerRevolution, 1);
AF_Stepper leftMotor(stepsPerRevolution, 2);

int wheelSpeed = 200;
int straightAmount = 3;
int turnAmount = 10;

// Setup Line Following Sensors
int left_sensor_pin = 9;
int right_sensor_pin = 10;
int left_sensor_state;
int right_sensor_state;


//Definition for Driving Straight
void goStraight(){
	leftMotor.step(straightAmount, FORWARD, MICROSTEP);
	rightMotor.step(straightAmount, FORWARD, MICROSTEP);
}

//Definition for Turning Left
void turnLeft(){
	//leftMotor.step(straightAmount, FORWARD, MICROSTEP);
	rightMotor.step(turnAmount, FORWARD, MICROSTEP);
}

//Definition for Turning Right
void turnRight(){
	leftMotor.step(turnAmount, FORWARD, MICROSTEP);
	//rightMotor.step(straightAmount, FORWARD, MICROSTEP);
}

//Definition for Driving Straight
void stopDriving(){
	leftMotor.release();
	rightMotor.release();
}


void setup() {
	
	// Set the Maximum Speed for the Glue Extruder in Steps per Second:
	glueExtruder.setMaxSpeed(100);
	
	//Set the Speed of the Wheels
	leftMotor.setSpeed(wheelSpeed);
	rightMotor.setSpeed(wheelSpeed); 
	
}


void loop() {
	
	// Set the speed of the glue in steps per second:
	glueExtruder.setSpeed(glueSpeed);
	glueExtruder.runSpeed();
	
	goStraight();
	
	
	//Read the Sensor Data
	left_sensor_state = digitalRead(left_sensor_pin);
	right_sensor_state = digitalRead(right_sensor_pin);
	
	// If Both Sensors Detect White Fabric, Go Straight
	if(right_sensor_state == 0 && left_sensor_state == 0){
		Serial.println("Drive Straight");
		goStraight();
	}
	
	// If the Left Sensor Detects the Line, Turn Left
	if(right_sensor_state == 0 && left_sensor_state == 1){
		Serial.println("Turn Left");
		turnLeft();
	}
	
	// If the Right Sensor Detects the Line, Turn Right
	if(right_sensor_state == 1 && left_sensor_state == 0){
		Serial.println("Turn Right");
		turnRight();
	}
	
	// If neither Sensor Detects White Fabric, Stop
	if(right_sensor_state == 1 && left_sensor_state == 1){
		Serial.println("Stop Driving");
		stopDriving();
	}
	
}